# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.file_schema import FileSchema  # noqa: E501


class TestFileSchema(unittest.TestCase):
    """FileSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FileSchema:
        """Test FileSchema
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `FileSchema`
        """
        model = FileSchema()  # noqa: E501
        if include_optional:
            return FileSchema(
                sample = haplohub.models.sample_schema.SampleSchema(
                    id = 56, 
                    sample_id = '', 
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                id = 56,
                filename = '',
                file_size = 56,
                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return FileSchema(
                filename = '',
                file_size = 56,
        )
        """

    def testFileSchema(self):
        """Test FileSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
