# coding: utf-8

# flake8: noqa
{{>partial_header}}

try:
    from ._version import __version__
except ImportError:
    __version__ = "0.0.0+unknown"

# import models into model package
{{#models}}
{{#model}}
from {{modelPackage}}.{{classFilename}} import {{classname}}
{{/model}}
{{/models}}
