# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.api.log_api import LogApi  # noqa: E501


class TestLogApi(unittest.TestCase):
    """LogApi unit test stubs"""

    def setUp(self) -> None:
        self.api = LogApi()

    def tearDown(self) -> None:
        pass

    def test_list_logs(self) -> None:
        """Test case for list_logs

        List logs  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
