# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.api.workflow_api import WorkflowApi  # noqa: E501


class TestWorkflowApi(unittest.TestCase):
    """WorkflowApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WorkflowApi()

    def tearDown(self) -> None:
        pass

    def test_get_workflow_run(self) -> None:
        """Test case for get_workflow_run

        Get workflow run  # noqa: E501
        """
        pass

    def test_list_workflow_runs(self) -> None:
        """Test case for list_workflow_runs

        List workflow runs  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
