# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.result_response_upload_request_response import ResultResponseUploadRequestResponse  # noqa: E501


class TestResultResponseUploadRequestResponse(unittest.TestCase):
    """ResultResponseUploadRequestResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResultResponseUploadRequestResponse:
        """Test ResultResponseUploadRequestResponse
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `ResultResponseUploadRequestResponse`
        """
        model = ResultResponseUploadRequestResponse()  # noqa: E501
        if include_optional:
            return ResultResponseUploadRequestResponse(
                status = 'success',
                result = haplohub.models.upload_request_response.UploadRequestResponse(
                    upload_request_id = '', 
                    upload_links = [
                        haplohub.models.upload_link.UploadLink(
                            original_file_path = '', 
                            file_path = '', 
                            signed_url = '', )
                        ], )
            )
        else:
            return ResultResponseUploadRequestResponse(
                result = haplohub.models.upload_request_response.UploadRequestResponse(
                    upload_request_id = '', 
                    upload_links = [
                        haplohub.models.upload_link.UploadLink(
                            original_file_path = '', 
                            file_path = '', 
                            signed_url = '', )
                        ], ),
        )
        """

    def testResultResponseUploadRequestResponse(self):
        """Test ResultResponseUploadRequestResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
