# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.api.report_template_api import ReportTemplateApi  # noqa: E501


class TestReportTemplateApi(unittest.TestCase):
    """ReportTemplateApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ReportTemplateApi()

    def tearDown(self) -> None:
        pass

    def test_create_report_template(self) -> None:
        """Test case for create_report_template

        Create report template  # noqa: E501
        """
        pass

    def test_delete_report_template(self) -> None:
        """Test case for delete_report_template

        Delete report template  # noqa: E501
        """
        pass

    def test_get_report_template(self) -> None:
        """Test case for get_report_template

        Get report template  # noqa: E501
        """
        pass

    def test_list_report_templates(self) -> None:
        """Test case for list_report_templates

        List report templates  # noqa: E501
        """
        pass

    def test_preview_report_template(self) -> None:
        """Test case for preview_report_template

        Preview report template  # noqa: E501
        """
        pass

    def test_update_report_template(self) -> None:
        """Test case for update_report_template

        Update report template  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
