python_dateutil >= 2.5.3
setuptools >= 21.0.0
urllib3 >= 1.25.3, < 3.0.0
pydantic >= 1.10.5, < 2
aenum >= 3.1.11
{{#asyncio}}
aiohttp >= 3.0.0
{{/asyncio}}
{{#hasHttpSignatureMethods}}
pycryptodome >= 3.9.0
{{/hasHttpSignatureMethods}}
