# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.accession_schema import AccessionSchema  # noqa: E501


class TestAccessionSchema(unittest.TestCase):
    """AccessionSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AccessionSchema:
        """Test AccessionSchema
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `AccessionSchema`
        """
        model = AccessionSchema()  # noqa: E501
        if include_optional:
            return AccessionSchema(
                chromosome = '',
                accession = '',
                length = 56,
                build = '',
                build_version = ''
            )
        else:
            return AccessionSchema(
                chromosome = '',
                accession = '',
                length = 56,
                build = '',
                build_version = '',
        )
        """

    def testAccessionSchema(self):
        """Test AccessionSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
