# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.api.file_api import FileApi  # noqa: E501


class TestFileApi(unittest.TestCase):
    """FileApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FileApi()

    def tearDown(self) -> None:
        pass

    def test_delete_file(self) -> None:
        """Test case for delete_file

        Delete file  # noqa: E501
        """
        pass

    def test_download_link(self) -> None:
        """Test case for download_link

        Get download link  # noqa: E501
        """
        pass

    def test_finish_uploading(self) -> None:
        """Test case for finish_uploading

        Finish uploading  # noqa: E501
        """
        pass

    def test_get_file(self) -> None:
        """Test case for get_file

        Get file  # noqa: E501
        """
        pass

    def test_list_files(self) -> None:
        """Test case for list_files

        List files  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
