# coding: utf-8

"""
HaploHub API

The HaploHub is a turnkey solution to securely store and interpret biomarkers, genetics, and 'omics data. Our customers use the HaploHub to:  * Store WGS, WES, low-pass, and array data with uniform REST interfaces to access variants  * Interpret genomic variants  * Generate risk scores for an individual  * Run the typical algorithms (phasing, imputation, etc.)  * Calculate 'biological age' or 'organ age' biomarkers  * Generate custom reports  The HaploHub platform is continually updated to remain at the forefront of scientific understanding.

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.algorithm_result_schema import AlgorithmResultSchema  # noqa: E501


class TestAlgorithmResultSchema(unittest.TestCase):
    """AlgorithmResultSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AlgorithmResultSchema:
        """Test AlgorithmResultSchema
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `AlgorithmResultSchema`
        """
        model = AlgorithmResultSchema()  # noqa: E501
        if include_optional:
            return AlgorithmResultSchema(
                id = '',
                algorithm_version_id = '',
                cohort_id = '',
                input = haplohub.models.input.Input(),
                output = haplohub.models.output.Output(),
                status = 'Pending',
                time_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                time_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return AlgorithmResultSchema(
                id = '',
                algorithm_version_id = '',
                cohort_id = '',
                input = haplohub.models.input.Input(),
                output = haplohub.models.output.Output(),
                status = 'Pending',
                time_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                time_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testAlgorithmResultSchema(self):
        """Test AlgorithmResultSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
