# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.api.member_api import MemberApi  # noqa: E501


class TestMemberApi(unittest.TestCase):
    """MemberApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MemberApi()

    def tearDown(self) -> None:
        pass

    def test_delete_member(self) -> None:
        """Test case for delete_member

        Delete member  # noqa: E501
        """
        pass

    def test_get_member(self) -> None:
        """Test case for get_member

        Get member  # noqa: E501
        """
        pass

    def test_list_members(self) -> None:
        """Test case for list_members

        List members  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
