# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401

from pydantic import BaseModel, Field, StrictStr

from haplohub.models.upload_requst_schema import UploadRequstSchema


class UploadLinkSchema(BaseModel):
    """
    UploadLinkSchema
    """

    upload_link: StrictStr = Field(...)
    upload_request: UploadRequstSchema = Field(...)
    __properties = ["upload_link", "upload_request"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UploadLinkSchema:
        """Create an instance of UploadLinkSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of upload_request
        if self.upload_request:
            _dict["upload_request"] = self.upload_request.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UploadLinkSchema:
        """Create an instance of UploadLinkSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UploadLinkSchema.parse_obj(obj)

        _obj = UploadLinkSchema.parse_obj(
            {
                "upload_link": obj.get("upload_link"),
                "upload_request": UploadRequstSchema.from_dict(obj.get("upload_request"))
                if obj.get("upload_request") is not None
                else None,
            }
        )
        return _obj
