# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest


class TestPredictionStatus(unittest.TestCase):
    """PredictionStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPredictionStatus(self):
        """Test PredictionStatus"""
        # inst = PredictionStatus()


if __name__ == "__main__":
    unittest.main()
