# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.paginated_response_sample_file_schema import PaginatedResponseSampleFileSchema  # noqa: E501


class TestPaginatedResponseSampleFileSchema(unittest.TestCase):
    """PaginatedResponseSampleFileSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedResponseSampleFileSchema:
        """Test PaginatedResponseSampleFileSchema
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `PaginatedResponseSampleFileSchema`
        """
        model = PaginatedResponseSampleFileSchema()  # noqa: E501
        if include_optional:
            return PaginatedResponseSampleFileSchema(
                status = 'success',
                total_count = 56,
                items = [
                    haplohub.models.sample_file_schema.SampleFileSchema(
                        id = 56, 
                        filename = '', 
                        file_size = 56, 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return PaginatedResponseSampleFileSchema(
                total_count = 56,
                items = [
                    haplohub.models.sample_file_schema.SampleFileSchema(
                        id = 56, 
                        filename = '', 
                        file_size = 56, 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
        )
        """

    def testPaginatedResponseSampleFileSchema(self):
        """Test PaginatedResponseSampleFileSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
