# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.result_list_response_variant_schema import ResultListResponseVariantSchema  # noqa: E501


class TestResultListResponseVariantSchema(unittest.TestCase):
    """ResultListResponseVariantSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResultListResponseVariantSchema:
        """Test ResultListResponseVariantSchema
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `ResultListResponseVariantSchema`
        """
        model = ResultListResponseVariantSchema()  # noqa: E501
        if include_optional:
            return ResultListResponseVariantSchema(
                status = 'success',
                items = [
                    haplohub.models.variant_schema.VariantSchema(
                        accession = '', 
                        position = 56, 
                        id = '', 
                        reference = '', 
                        alternate = [
                            ''
                            ], 
                        quality = 1.337, )
                    ]
            )
        else:
            return ResultListResponseVariantSchema(
                items = [
                    haplohub.models.variant_schema.VariantSchema(
                        accession = '', 
                        position = 56, 
                        id = '', 
                        reference = '', 
                        alternate = [
                            ''
                            ], 
                        quality = 1.337, )
                    ],
        )
        """

    def testResultListResponseVariantSchema(self):
        """Test ResultListResponseVariantSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
