# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.member_schema import MemberSchema  # noqa: E501


class TestMemberSchema(unittest.TestCase):
    """MemberSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MemberSchema:
        """Test MemberSchema
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `MemberSchema`
        """
        model = MemberSchema()  # noqa: E501
        if include_optional:
            return MemberSchema(
                id = 56,
                patient_id = '',
                first_name = '',
                last_name = '',
                gender = '',
                birth_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return MemberSchema(
        )
        """

    def testMemberSchema(self):
        """Test MemberSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
