# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.get_hgvs_response import GetHgvsResponse  # noqa: E501


class TestGetHgvsResponse(unittest.TestCase):
    """GetHgvsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetHgvsResponse:
        """Test GetHgvsResponse
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `GetHgvsResponse`
        """
        model = GetHgvsResponse()  # noqa: E501
        if include_optional:
            return GetHgvsResponse(
                status = 'success',
                result = haplohub.models.hgvs_dosage_schema.HgvsDosageSchema(
                    sample_id = '', 
                    description = '', 
                    dosage = 56, )
            )
        else:
            return GetHgvsResponse(
                result = haplohub.models.hgvs_dosage_schema.HgvsDosageSchema(
                    sample_id = '', 
                    description = '', 
                    dosage = 56, ),
        )
        """

    def testGetHgvsResponse(self):
        """Test GetHgvsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
