# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.api.sample_file_api import SampleFileApi  # noqa: E501


class TestSampleFileApi(unittest.TestCase):
    """SampleFileApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SampleFileApi()

    def tearDown(self) -> None:
        pass

    def test_delete_sample_file(self) -> None:
        """Test case for delete_sample_file

        Delete sample file  # noqa: E501
        """
        pass

    def test_download_link(self) -> None:
        """Test case for download_link

        Get download link  # noqa: E501
        """
        pass

    def test_finish_uploading(self) -> None:
        """Test case for finish_uploading

        Finish uploading  # noqa: E501
        """
        pass

    def test_get_sample_file(self) -> None:
        """Test case for get_sample_file

        Get sample file  # noqa: E501
        """
        pass

    def test_list_sample_files(self) -> None:
        """Test case for list_sample_files

        List sample files  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
