"""
{{#appName}}
    {{{.}}}

{{/appName}}
{{#appDescription}}
    {{{.}}}

{{/appDescription}}
    {{#version}}
    The version of the OpenAPI document: {{{.}}}
    {{/version}}
    {{#infoEmail}}
    Contact: {{{.}}}
    {{/infoEmail}}
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501
