# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.api.metadata_api import MetadataApi  # noqa: E501


class TestMetadataApi(unittest.TestCase):
    """MetadataApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MetadataApi()

    def tearDown(self) -> None:
        pass

    def test_accession(self) -> None:
        """Test case for accession

        Each accession is a string of DNA that is used as a reference. These are defined by https://www.ncbi.nlm.nih.gov/grc/human/data?asm=GRCh38  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
