# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.api.cohort_api import CohortApi  # noqa: E501


class TestCohortApi(unittest.TestCase):
    """CohortApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CohortApi()

    def tearDown(self) -> None:
        pass

    def test_create_cohort(self) -> None:
        """Test case for create_cohort

        Create cohort  # noqa: E501
        """
        pass

    def test_delete_cohort(self) -> None:
        """Test case for delete_cohort

        Delete cohort  # noqa: E501
        """
        pass

    def test_get_cohort(self) -> None:
        """Test case for get_cohort

        Get cohort  # noqa: E501
        """
        pass

    def test_list_cohorts(self) -> None:
        """Test case for list_cohorts

        List cohorts  # noqa: E501
        """
        pass

    def test_update_cohort(self) -> None:
        """Test case for update_cohort

        Update cohort  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
