# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.api.report_api import ReportApi  # noqa: E501


class TestReportApi(unittest.TestCase):
    """ReportApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ReportApi()

    def tearDown(self) -> None:
        pass

    def test_create_report(self) -> None:
        """Test case for create_report

        Create report  # noqa: E501
        """
        pass

    def test_delete_report(self) -> None:
        """Test case for delete_report

        Delete report  # noqa: E501
        """
        pass

    def test_get_report(self) -> None:
        """Test case for get_report

        Get report  # noqa: E501
        """
        pass

    def test_list_reports(self) -> None:
        """Test case for list_reports

        List reports  # noqa: E501
        """
        pass

    def test_preview_report(self) -> None:
        """Test case for preview_report

        Preview report  # noqa: E501
        """
        pass

    def test_update_report(self) -> None:
        """Test case for update_report

        Update report  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
