# coding: utf-8

"""
HaploHub API

The HaploHub is a turnkey solution to securely store and interpret biomarkers, genetics, and 'omics data. Our customers use the HaploHub to:  * Store WGS, WES, low-pass, and array data with uniform REST interfaces to access variants  * Interpret genomic variants  * Generate risk scores for an individual  * Run the typical algorithms (phasing, imputation, etc.)  * Calculate 'biological age' or 'organ age' biomarkers  * Generate custom reports  The HaploHub platform is continually updated to remain at the forefront of scientific understanding.

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from datetime import datetime
from typing import Optional

from pydantic import BaseModel, Field, StrictStr, constr

from haplohub.models.algorithm_version_schema import AlgorithmVersionSchema
from haplohub.models.id import Id


class AlgorithmSchema(BaseModel):
    """
    AlgorithmSchema
    """

    id: Id = Field(...)
    latest_version: Optional[AlgorithmVersionSchema] = None
    name: constr(strict=True, max_length=255) = Field(...)
    description: StrictStr = Field(...)
    owner: constr(strict=True, max_length=255) = Field(...)
    modified: Optional[datetime] = None
    created: Optional[datetime] = None
    __properties = ["id", "latest_version", "name", "description", "owner", "modified", "created"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AlgorithmSchema:
        """Create an instance of AlgorithmSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of id
        if self.id:
            _dict["id"] = self.id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of latest_version
        if self.latest_version:
            _dict["latest_version"] = self.latest_version.to_dict()
        # set to None if latest_version (nullable) is None
        # and __fields_set__ contains the field
        if self.latest_version is None and "latest_version" in self.__fields_set__:
            _dict["latest_version"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AlgorithmSchema:
        """Create an instance of AlgorithmSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AlgorithmSchema.parse_obj(obj)

        _obj = AlgorithmSchema.parse_obj(
            {
                "id": Id.from_dict(obj.get("id")) if obj.get("id") is not None else None,
                "latest_version": AlgorithmVersionSchema.from_dict(obj.get("latest_version"))
                if obj.get("latest_version") is not None
                else None,
                "name": obj.get("name"),
                "description": obj.get("description"),
                "owner": obj.get("owner"),
                "modified": obj.get("modified"),
                "created": obj.get("created"),
            }
        )
        return _obj
