# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import json

from aenum import Enum


class PredictionStatus(str, Enum):
    """
    PredictionStatus
    """

    """
    allowed enum values
    """
    PENDING = "pending"
    RUNNING = "running"
    FAILED = "failed"
    STOPPED = "stopped"

    @classmethod
    def from_json(cls, json_str: str):
        """Create an instance of PredictionStatus from a JSON string"""
        return PredictionStatus(json.loads(json_str))
