# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Optional

from pydantic import BaseModel, StrictInt, StrictStr


class ListModelsRequest(BaseModel):
    """
    ListModelsRequest
    """

    page: Optional[StrictInt] = 1
    page_size: Optional[StrictInt] = 10
    search: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    __properties = ["page", "page_size", "search", "name"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ListModelsRequest:
        """Create an instance of ListModelsRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # set to None if search (nullable) is None
        # and __fields_set__ contains the field
        if self.search is None and "search" in self.__fields_set__:
            _dict["search"] = None

        # set to None if name (nullable) is None
        # and __fields_set__ contains the field
        if self.name is None and "name" in self.__fields_set__:
            _dict["name"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ListModelsRequest:
        """Create an instance of ListModelsRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ListModelsRequest.parse_obj(obj)

        _obj = ListModelsRequest.parse_obj(
            {
                "page": obj.get("page") if obj.get("page") is not None else 1,
                "page_size": obj.get("page_size") if obj.get("page_size") is not None else 10,
                "search": obj.get("search"),
                "name": obj.get("name"),
            }
        )
        return _obj
